@@ -23,7 +23,7 @@ from django.conf.urls import url
 
 from django_rs import views
 
-
 urlpatterns = [
-    url(r'^(?P<app>[-\w.]+)/(?P<scenario>\w+)/', views.index, name='index')
+    url(r'^$', views.index, name='index'),
+    url(r'^(?P<app>[-\w.]+)/(?P<scenario>\w+)/', views.scenario, name='scenario')
 ]
